@@ -20,7 +20,6 @@ from typing import Generator
 from typing import Optional
 
 import logging
-import os
 
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -34,9 +33,9 @@ from gajim.common import events
 from gajim.common import ged
 from gajim.common.client import Client
 from gajim.common.const import Direction
+from gajim.common.const import Display
 from gajim.common.const import SimpleClientState
 from gajim.common.ged import EventHelper
-from gajim.common.helpers import ask_for_status_message
 from gajim.common.i18n import _
 from gajim.common.modules.bytestream import is_transfer_active
 from gajim.plugins.pluginmanager import PluginManifest
@@ -126,7 +125,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             ('account-enabled', ged.GUI1, self._on_account_enabled),
             ('account-disabled', ged.GUI1, self._on_account_disabled),
             ('allow-gajim-update-check', ged.GUI1, self._on_allow_gajim_update),
-            ('gajim-update-available', ged.GUI1, self._on_gajim_update_available),
+            ('gajim-update-available', ged.GUI1,
+             self._on_gajim_update_available),
             ('roster-item-exchange', ged.GUI1, self._on_roster_item_exchange),
             ('plain-connection', ged.GUI1, self._on_plain_connection),
             ('password-required', ged.GUI1, self._on_password_required),
@@ -155,24 +155,50 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             client.connect_signal('state-changed',
                                   self._on_client_state_changed)
 
-    def _prepare_window(self) -> None:
-        if app.settings.get('main_window_skip_taskbar'):
-            self.set_property('skip-taskbar-hint', True)
+    def is_minimized(self) -> bool:
+        if app.is_display(Display.WAYLAND):
+            # There is no way to discover if a window is minimized on wayland
+            return False
 
+        window = self.get_window()
+        assert window is not None
+        return bool(Gdk.WindowState.ICONIFIED & window.get_state())
+
+    def is_withdrawn(self) -> bool:
+        window = self.get_window()
+        assert window is not None
+        return bool(Gdk.WindowState.WITHDRAWN & window.get_state())
+
+    def hide(self) -> None:
+        save_main_window_position()
+        Gtk.ApplicationWindow.hide(self)
+
+    def show(self) -> None:
         restore_main_window_position()
+        self.present_with_time(Gtk.get_current_event_time())
+
+    def minimize(self) -> None:
+        self.iconify()
+
+    def unminimize(self) -> None:
+        self.deiconify()
+        self.present_with_time(Gtk.get_current_event_time())
+
+    def _prepare_window(self) -> None:
         window_width = app.settings.get('mainwin_width')
         window_height = app.settings.get('mainwin_height')
         resize_window(self, window_width, window_height)
+
+        self.set_skip_taskbar_hint(not app.settings.get('show_in_taskbar'))
+
         self.show_all()
 
         show_main_window = app.settings.get('show_main_window_on_startup')
-        if (show_main_window == 'always' or
-                not app.settings.get('show_trayicon')):
-            # Without trayicon, we have to show the main window
-            return
+        if show_main_window == 'never':
+            self.hide()
 
-        if (show_main_window == 'never' or
-                not app.settings.get('last_main_window_visible')):
+        elif (show_main_window == 'last_state' and
+                not app.settings.get('is_window_visible')):
             self.hide()
 
     def _on_account_enabled(self, event: events.AccountEnabled) -> None:
@@ -317,6 +343,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             'switch-tab-7',
             'switch-tab-8',
             'switch-tab-9',
+            'toggle-chat-list',
         ]
 
         disabled_for_emacs = (
@@ -337,31 +364,31 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                    action: Gio.SimpleAction,
                    _param: Optional[GLib.Variant]) -> Optional[int]:
 
-        control = self.get_active_control()
-        if control is None:
-            return None
-        log.info('Activate action: %s, active control: %s',
-                 action.get_name(), control.contact.jid)
-
         action_name = action.get_name()
+        log.info('Activate action: %s', action_name)
 
-        res = control.delegate_action(action_name)
-        if res != Gdk.EVENT_PROPAGATE:
-            return res
+        if action_name == 'escape' and self._chat_page.hide_search():
+            return None
 
-        if action_name == 'escape':
-            if self._chat_page.hide_search():
-                return None
+        control = self.get_active_control()
+        if control is not None:
 
-            if app.settings.get('escape_key_closes'):
+            res = control.delegate_action(action_name)
+            if res != Gdk.EVENT_PROPAGATE:
+                return res
+
+            if action_name == 'escape':
+                if app.settings.get('escape_key_closes'):
+                    self._chat_page.remove_chat(control.account,
+                                                control.contact.jid)
+                    return None
+
+            elif action_name == 'close-tab':
                 self._chat_page.remove_chat(control.account,
                                             control.contact.jid)
                 return None
 
-        elif action_name == 'close-tab':
-            self._chat_page.remove_chat(control.account, control.contact.jid)
-
-        elif action_name == 'switch-next-tab':
+        if action_name == 'switch-next-tab':
             self.select_next_chat(Direction.NEXT)
 
         elif action_name == 'switch-prev-tab':
@@ -377,6 +404,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             number = int(action_name[-1]) - 1
             self.select_chat_number(number)
 
+        elif action_name == 'toggle-chat-list':
+            self._chat_page.toggle_chat_list()
+
         return None
 
     def _on_window_motion_notify(self,
@@ -395,45 +425,52 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
     def _on_window_delete(self,
                           _widget: Gtk.ApplicationWindow,
                           _event: Gdk.Event
-                          ) -> bool:
-        # Main window X button was clicked
-        if app.settings.get('quit_on_main_window_x_button'):
+                          ) -> int:
+
+        action = app.settings.get('action_on_close')
+        if action == 'hide':
+            self.hide()
+            return Gdk.EVENT_STOP
+
+        if action == 'minimize':
+            self.minimize()
+            return Gdk.EVENT_STOP
+
+        if not app.settings.get('confirm_on_window_delete'):
             self.quit()
-        else:
-            if (app.settings.get('allow_hide_roster') or
-                    app.app.systray.is_visible()):
-                save_main_window_position()
-                if (os.name == 'nt' or
-                        app.settings.get('hide_on_main_window_x_button')):
-                    self.hide()
-                else:
-                    self.iconify()
-                return True
+            return Gdk.EVENT_STOP
 
-            def _on_ok(is_checked: bool) -> None:
-                if is_checked:
-                    app.settings.set('quit_on_main_window_x_button', True)
-                self.quit()
+        def _on_ok(is_checked: bool) -> None:
+            if is_checked:
+                app.settings.set('confirm_on_window_delete', False)
+            self.quit()
 
-            ConfirmationCheckDialog(
-                _('Quit Gajim'),
-                _('You are about to quit Gajim'),
-                _('Are you sure you want to quit Gajim?'),
-                _('_Always quit when closing Gajim'),
-                [DialogButton.make('Cancel'),
-                 DialogButton.make('Remove',
-                                   text=_('_Quit'),
-                                   callback=_on_ok)]).show()
-        return True
+        ConfirmationCheckDialog(
+            _('Quit Gajim'),
+            _('You are about to quit Gajim'),
+            _('Are you sure you want to quit Gajim?'),
+            _('_Don’t ask again'),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Remove',
+                               text=_('_Quit'),
+                               callback=_on_ok)]).show()
+
+        return Gdk.EVENT_STOP
 
     def _on_window_state_changed(self,
                                  window: MainWindow,
                                  event: Gdk.EventWindowState) -> None:
 
-        iconified = bool(Gdk.WindowState.ICONIFIED & event.new_window_state)
-        hidden = bool(Gdk.WindowState.WITHDRAWN & event.new_window_state)
-        visible = not (iconified or hidden)
-        app.settings.set('last_main_window_visible', visible)
+        states = Gdk.WindowState.WITHDRAWN | Gdk.WindowState.ICONIFIED
+        if states & event.changed_mask:
+            is_withdrawn = bool(Gdk.WindowState.WITHDRAWN &
+                                event.new_window_state)
+            is_iconified = bool(Gdk.WindowState.ICONIFIED &
+                                event.new_window_state)
+            log.debug('Window state changed: ICONIFIED: %s, WITHDRAWN: %s',
+                      is_iconified, is_withdrawn)
+
+            app.settings.set('is_window_visible', not is_withdrawn)
 
     def _set_startup_finished(self) -> None:
         self._startup_finished = True
@@ -844,13 +881,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self._main_stack.process_event(event)
 
     def quit(self) -> None:
-        accounts = list(app.connections.keys())
-        get_msg = False
-        for acct in accounts:
-            if app.account_is_available(acct):
-                get_msg = True
-                break
-
         save_main_window_position()
         window_width, window_height = self.get_size()
         app.settings.set('mainwin_width', window_width)
@@ -906,11 +936,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 return
             on_continue2(message)
 
-        if get_msg and ask_for_status_message('offline'):
-            print('TODO: Let user choose status message')
-            on_continue('')  # status message here
-        else:
-            on_continue('')
+        on_continue('')
 
     def _on_plugin_updates_available(self,
                                      _repository: PluginRepository,
